==> react-daily-components-0.5.4.tgz: package/lib/esm/components/inputs/Button/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { useTheme } from "@emotion/react";
import { forwardRef, useCallback } from "react";
import uesDebounce from "../../../hooks/useDebounce";
import useThrottle from "../../../hooks/useThrottle";
import { getElementProps } from "../../../utilities/props";
import * as Styled from "./style";
import { rippleEffect } from "../../../utilities/css";
var VARIANTS = {
    text: Styled.TextButton,
    contained: Styled.ContainedButton,
    outlined: Styled.OutlinedButton,
};
/**
 * Button Component
 */
var Button = forwardRef(function (props, forwardedRef) {
    var theme = useTheme();
    var _a = props.onClick, onClick = _a === void 0 ? function () { } : _a, _b = props.variant, variant = _b === void 0 ? "contained" : _b, _c = props.debounce, debounce = _c === void 0 ? 0 : _c, _d = props.throttle, throttle = _d === void 0 ? 0 : _d;
    var throttledFunction = useThrottle(onClick, throttle);
    var debouncedFunction = uesDebounce(throttledFunction, debounce);
    var handleClick = useCallback(function (event) {
        rippleEffect(event, theme, variant !== "contained");
        debouncedFunction(event);
    }, [onClick]);
    var style = __assign(__assign({}, getElementProps(props)), props.style);
    var Button = VARIANTS[variant];
    return (_jsx(Button, __assign({}, props, { ref: forwardedRef, onClick: handleClick, style: style })));
});
export default Button;

==> react-daily-components-0.5.6.tgz: package/lib/esm/components/inputs/Button/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { useTheme } from "@emotion/react";
import { forwardRef, useCallback } from "react";
import uesDebounce from "../../../hooks/useDebounce";
import useThrottle from "../../../hooks/useThrottle";
import * as Styled from "./style";
import { rippleEffect } from "../../../utilities/css";
import { getStyleProps } from "../../../utilities/props";
var VARIANTS = {
    text: Styled.TextButton,
    contained: Styled.ContainedButton,
    outlined: Styled.OutlinedButton,
};
/**
 * Button Component
 */
var Button = forwardRef(function (props, forwardedRef) {
    var theme = useTheme();
    var _a = props.onClick, onClick = _a === void 0 ? function () { } : _a, _b = props.variant, variant = _b === void 0 ? "contained" : _b, _c = props.debounce, debounce = _c === void 0 ? 0 : _c, _d = props.throttle, throttle = _d === void 0 ? 0 : _d;
    var throttledFunction = useThrottle(onClick, throttle);
    var debouncedFunction = uesDebounce(throttledFunction, debounce);
    var handleClick = useCallback(function (event) {
        rippleEffect(event, theme, variant !== "contained");
        debouncedFunction(event);
    }, [onClick]);
    var Button = VARIANTS[variant];
    return (_jsx(Button, __assign({}, props, { ref: forwardedRef, onClick: handleClick, style: getStyleProps(props) })));
});
export default Button;
